# TDes

tdes is a Python CLI application for encrypting and decrypting files tool using [triple DES](https://en.wikipedia.org/wiki/Triple_DES).

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install tdes.

```bash
pip install tdes
```

## Usage

```bash
$tdes encrypt --path "E:\files\image.png"

$tdes encryptall --path "E:\files\"

$tdes decrypt --path "E:\files\image.png" --key1 hGGe314l --key2 342XCFGs
```

## Contributing

Pull requests are welcome. For major changes, please open an issue first
to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License

[MIT](https://choosealicense.com/licenses/mit/)